@@ -11,8 +11,8 @@ DEFAULTS = {
     'LOCK_KEY': 'lock',
     'LOCK_TIMEOUT': DEFAULT_MAX_INTERVAL * 5,
     'LOCK_SLEEP':  DEFAULT_MAX_INTERVAL,
-    'TASK_STALE_TIME_LIMIT': None,
-    'TASK_STALE_TIMELIMIT_FROM_TIME_LIMIT_CONSTANT': None,
+    'DEFAULT_TASK_STALE_TIME_LIMIT': None,
+    'DEFAULT_TASK_MAX_QUEUE_WAITING_TIME': None,
     'AUTO_GENERATE_TASKS_DJANGO_COMMANDS': {},
     'AUTO_GENERATE_TASKS_BASE': 'django_celery_extensions.task.DjangoTask',
     'AUTO_GENERATE_TASKS_DEFAULT_CELERY_KWARGS': {},
